/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class MessagesDirective extends ComponentMessages {
    /* Tabs */
    /**
     * Sets the name for the **Home** toolbar tab.
     */
    home;
    /**
     * Sets the name for the **File** toolbar tab.
     */
    file;
    /**
     * Sets the name for the **Insert** toolbar tab.
     */
    insert;
    /**
     * Sets the name for the **Format** toolbar tab.
     */
    formatTab;
    /**
     * Sets the name for the **Data** toolbar tab.
     */
    dataTab;
    /* Section of Tools Messages */
    /**
     * Sets the title for the **Save** File tool.
     */
    saveFile;
    /**
     * Sets the title for the **Load File** tool.
     */
    loadFile;
    /**
     * Sets the title for the **Bold** tool.
     */
    bold;
    /**
     * Sets the title for the **Data Validation** tool.
     */
    dataValidation;
    /**
     * Sets the label text for the Cell Range input in the data validation dialog.
     */
    validationCellRange;
    /**
     * Sets the label text for the Criteria dropdown in the data validation dialog.
     */
    validationCriteria;
    /**
     * Sets the label text for the Comparer dropdown in the data validation dialog.
     */
    validationComparer;
    /**
     * Sets the label text for the Min value in the data validation dialog.
     */
    validationMinValue;
    /**
     * Sets the label text for the Max value in the data validation dialog.
     */
    validationMaxValue;
    /**
     * Sets the label text for the Start value in the data validation dialog.
     */
    validationStartValue;
    /**
     * Sets the label text for the End value in the data validation dialog.
     */
    validationEndValue;
    /**
     * Sets the label text for the Value in the data validation dialog.
     */
    validationValue;
    /**
     * Sets the label text for the Show list button checkbox in the data validation dialog.
     */
    validationShowListButtonCheckbox;
    /**
     * Sets the label text for the Show date button checkbox in the data validation dialog.
     */
    validationShowDateButtonCheckbox;
    /**
     * Sets the label text for the Ignore blank checkbox in the data validation dialog.
     */
    validationIgnoreBlankCheckbox;
    /**
     * Sets the label text for the On invalid data option in the data validation dialog.
     */
    validationOnInvalidData;
    /**
     * Sets the label text for the Reject input radio button in the data validation dialog.
     */
    validationRejectInput;
    /**
     * Sets the label text for the Show warning radio button in the data validation dialog.
     */
    validationShowWarning;
    /**
     * Sets the label text for the Show hint checkbox in the data validation dialog.
     */
    validationShowHint;
    /**
     * Sets the text for the Any value validation criteria.
     */
    anyValueValidationCriteria;
    /**
     * Sets the text for the Number validation criteria.
     */
    numberValidationCriteria;
    /**
     * Sets the text for the Text validation criteria.
     */
    textValidationCriteria;
    /**
     * Sets the text for the Date validation criteria.
     */
    dateValidationCriteria;
    /**
     * Sets the text for the Custom Formula validation criteria.
     */
    customFormulaValidationCriteria;
    /**
     * Sets the text for the List validation criteria.
     */
    listValidationCriteria;
    /**
     * Sets the text for the greater than validation comparer.
     */
    greaterThanValidationComparer;
    /**
     * Sets the text for the less than validation comparer.
     */
    lessThanValidationComparer;
    /**
     * Sets the text for the between validation comparer.
     */
    betweenValidationComparer;
    /**
     * Sets the text for the not between validation comparer.
     */
    notBetweenValidationComparer;
    /**
     * Sets the text for the equal to validation comparer.
     */
    equalToValidationComparer;
    /**
     * Sets the text for the not equal to validation comparer.
     */
    notEqualToValidationComparer;
    /**
     * Sets the text for the greater than or equal to validation comparer.
     */
    greaterThanOrEqualToValidationComparer;
    /**
     * Sets the text for the less than or equal to validation comparer.
     */
    lessThanOrEqualToValidationComparer;
    /**
     * Sets the label text for the Custom hint input in the data validation dialog.
     */
    validationHintMessage;
    /**
     * Sets the label text for the Custom hint title input in the data validation dialog.
     */
    validationHintTitle;
    /**
     * Sets the title for the **Italic** tool.
     */
    italic;
    /**
     * Sets the title for the **Underline** tool.
     */
    underline;
    /**
     * Sets the title for the **Format** tool.
     */
    format;
    /**
     * Sets the title for the **Font Family** tool.
     */
    fontFamily;
    /**
     * Sets the title for the **Font Size** tool.
     */
    fontSize;
    /**
     * Sets the title for the **Undo** tool.
     */
    undo;
    /**
     * Sets the title for the **Redo** tool.
     */
    redo;
    /**
     * Sets the title for the tool that changes the text background color.
     */
    background;
    /**
     * Sets the title for the tool that changes the text font color.
     */
    color;
    /**
     * Sets the title for the **Grid Lines** tool.
     */
    gridLines;
    /**
     * Sets the title for the tool that adds a new column before the selected column.
     */
    addColumnLeft;
    /**
     * Sets the title for the tool that adds a new column after the selected column.
     */
    addColumnRight;
    /**
     * Sets the title for the tool that adds a new row below the selected row.
     */
    addRowBelow;
    /**
     * Sets the title for the tool that adds a new row above the selected row.
     */
    addRowAbove;
    /**
     * Sets the title for the tool that deletes a column.
     */
    deleteColumn;
    /**
     * Sets the title for the tool that deletes a row.
     */
    deleteRow;
    /**
     * Sets the title for the **Text Wrap** tool.
     */
    wrap;
    /**
     * Sets the title for the **Text Align** tool.
     */
    align;
    /**
     * Sets the title for the **Text Align Horizontal** tool.
     */
    alignHorizontal;
    /**
     * Sets the title for the **Text Align Vertical** tool.
     */
    alignVertical;
    /**
     * Sets the title for the **Text Align Left** tool.
     */
    alignLeft;
    /**
     * Sets the title for the **Text Align Center** tool.
     */
    alignCenter;
    /**
     * Sets the title for the **Text Align Right** tool.
     */
    alignRight;
    /**
     * Sets the title for the **Text Align Justify** tool.
     */
    alignJustify;
    /**
     * Sets the title for the **Text Align Top** tool.
     */
    alignTop;
    /**
     * Sets the title for the **Text Align Middle** tool.
     */
    alignMiddle;
    /**
     * Sets the title for the **Text Align Bottom** tool.
     */
    alignBottom;
    /* Dialogs */
    /**
     * Sets the text for the **Apply** button in all Spreadsheet dialogs.
     */
    dialogApply;
    /* Dialogs */
    /**
     * Sets the text for the **Cancel** button in all Spreadsheet dialogs.
     */
    dialogCancel;
    /**
     * Sets the text for the **Delete** button in the Delete sheet dialog.
     */
    dialogDelete;
    /**
     * Sets the text for the **Rename** button in the Rename sheet dialog.
     */
    dialogRename;
    /**
     * Sets the text for the **Insert** button in all Spreadsheet dialogs.
     */
    dialogInsert;
    /**
     * Sets the text for the **Remove** button in all Spreadsheet dialogs.
     */
    dialogRemove;
    /**
     * Sets the text for the **Remove link** button in the Link tool dialog.
     */
    dialogRemoveLink;
    /**
     * Sets the title for the Delete sheet dialog.
     */
    delete;
    /**
     * Sets the title for the Rename sheet dialog.
     */
    rename;
    /**
     * Sets the title for the Name Box input.
     */
    nameBox;
    /**
     * Sets the title for the Formula input.
     */
    formulaInput;
    /**
     * Sets the title for the Add new sheet button.
     */
    addSheet;
    /**
     * Sets the title for the Sheets menu button.
     */
    sheetsMenu;
    /**
     * Sets the text for the View toolbar tab.
     */
    view;
    /**
     * Sets the title for the Cells Merge tool.
     */
    merge;
    /**
     * Sets the title for the Merge horizontally tool.
     */
    mergeHorizontally;
    /**
     * Sets the title for the Merge vertically tool.
     */
    mergeVertically;
    /**
     * Sets the title for the Merge all tool.
     */
    mergeAll;
    /**
     * Sets the title for the Unmerge tool.
     */
    unmerge;
    /**
     * Sets the title for the tool that inserts a link.
     */
    insertLink;
    /**
     * Sets the title for the tool that increases decimals.
     */
    increaseDecimal;
    /**
     * Sets the title for the tool that decreases decimals.
     */
    decreaseDecimal;
    /**
     * Sets the title for the tool that increases the cell font size.
     */
    increaseFontSize;
    /**
     * Sets the title for the tool that decreases the cell font size.
     */
    decreaseFontSize;
    /**
     * Sets the content for the dialog that warns about an unsupported file type.
     */
    openUnsupported;
    /**
     * Sets the content for the dialog that warns about modifying a merged cell.
     */
    modifyMerged;
    /**
     * Sets the content for the dialog that warns about modifying a disabled cell.
     */
    cannotModifyDisabled;
    /**
     * Sets the text for the **OK** dialog button.
     */
    dialogOk;
    /**
     * Sets the title for an error dialog.
     */
    dialogError;
    /**
     * Sets the content for the dialog that warns about duplicated sheet name.
     */
    duplicateSheetName;
    /**
     * Sets the Copy command text.
     */
    copy;
    /**
     * Sets the Cut command text.
     */
    cut;
    /**
     * Sets the Paste command text.
     */
    paste;
    /**
     * Sets the Hide row command text.
     */
    hideRow;
    /**
     * Sets the Unhide row command text.
     */
    unhideRow;
    /**
     * Sets the Hide column command text.
     */
    hideColumn;
    /**
     * Sets the Unhide column command text.
     */
    unhideColumn;
    /**
     * Sets the text for the Sheet menu Delete option.
     */
    sheetDelete;
    /**
     * Sets the text for the Sheet menu Rename option.
     */
    sheetRename;
    /**
     * Sets the text for the Sheet menu Hide option.
     */
    sheetHide;
    /**
     * Sets the text for the Sheet menu Duplicate option.
     */
    sheetDuplicate;
    /**
     * Sets the text for the Sheet menu Move Left option.
     */
    sheetMoveLeft;
    /**
     * Sets the text for the Sheet menu Move Right option.
     */
    sheetMoveRight;
    /**
     * Sets the content for the dialog that warns about invalid name input.
     *
     * The content consists of a two-part message - the input value and a localizable string.
     * For user value input **A1%**, the default dialog content will be **Invalid name: A1%**.
     *
     * To allow reordering the input value and the localizable part, the `invalidNameError` accepts a string with a
     * placeholder for the input value, for example, **{inputValue} is invalid**. The `{inputValue}` placeholder will be replaced
     * internally with the current value, and the resulting label will be rendered as **A1% is invalid**.
     */
    invalidNameError;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessagesDirective, isStandalone: true, selector: "[kendoSpreadsheetMessages]", inputs: { home: "home", file: "file", insert: "insert", formatTab: "formatTab", dataTab: "dataTab", saveFile: "saveFile", loadFile: "loadFile", bold: "bold", dataValidation: "dataValidation", validationCellRange: "validationCellRange", validationCriteria: "validationCriteria", validationComparer: "validationComparer", validationMinValue: "validationMinValue", validationMaxValue: "validationMaxValue", validationStartValue: "validationStartValue", validationEndValue: "validationEndValue", validationValue: "validationValue", validationShowListButtonCheckbox: "validationShowListButtonCheckbox", validationShowDateButtonCheckbox: "validationShowDateButtonCheckbox", validationIgnoreBlankCheckbox: "validationIgnoreBlankCheckbox", validationOnInvalidData: "validationOnInvalidData", validationRejectInput: "validationRejectInput", validationShowWarning: "validationShowWarning", validationShowHint: "validationShowHint", anyValueValidationCriteria: "anyValueValidationCriteria", numberValidationCriteria: "numberValidationCriteria", textValidationCriteria: "textValidationCriteria", dateValidationCriteria: "dateValidationCriteria", customFormulaValidationCriteria: "customFormulaValidationCriteria", listValidationCriteria: "listValidationCriteria", greaterThanValidationComparer: "greaterThanValidationComparer", lessThanValidationComparer: "lessThanValidationComparer", betweenValidationComparer: "betweenValidationComparer", notBetweenValidationComparer: "notBetweenValidationComparer", equalToValidationComparer: "equalToValidationComparer", notEqualToValidationComparer: "notEqualToValidationComparer", greaterThanOrEqualToValidationComparer: "greaterThanOrEqualToValidationComparer", lessThanOrEqualToValidationComparer: "lessThanOrEqualToValidationComparer", validationHintMessage: "validationHintMessage", validationHintTitle: "validationHintTitle", italic: "italic", underline: "underline", format: "format", fontFamily: "fontFamily", fontSize: "fontSize", undo: "undo", redo: "redo", background: "background", color: "color", gridLines: "gridLines", addColumnLeft: "addColumnLeft", addColumnRight: "addColumnRight", addRowBelow: "addRowBelow", addRowAbove: "addRowAbove", deleteColumn: "deleteColumn", deleteRow: "deleteRow", wrap: "wrap", align: "align", alignHorizontal: "alignHorizontal", alignVertical: "alignVertical", alignLeft: "alignLeft", alignCenter: "alignCenter", alignRight: "alignRight", alignJustify: "alignJustify", alignTop: "alignTop", alignMiddle: "alignMiddle", alignBottom: "alignBottom", dialogApply: "dialogApply", dialogCancel: "dialogCancel", dialogDelete: "dialogDelete", dialogRename: "dialogRename", dialogInsert: "dialogInsert", dialogRemove: "dialogRemove", dialogRemoveLink: "dialogRemoveLink", delete: "delete", rename: "rename", nameBox: "nameBox", formulaInput: "formulaInput", addSheet: "addSheet", sheetsMenu: "sheetsMenu", view: "view", merge: "merge", mergeHorizontally: "mergeHorizontally", mergeVertically: "mergeVertically", mergeAll: "mergeAll", unmerge: "unmerge", insertLink: "insertLink", increaseDecimal: "increaseDecimal", decreaseDecimal: "decreaseDecimal", increaseFontSize: "increaseFontSize", decreaseFontSize: "decreaseFontSize", openUnsupported: "openUnsupported", modifyMerged: "modifyMerged", cannotModifyDisabled: "cannotModifyDisabled", dialogOk: "dialogOk", dialogError: "dialogError", duplicateSheetName: "duplicateSheetName", copy: "copy", cut: "cut", paste: "paste", hideRow: "hideRow", unhideRow: "unhideRow", hideColumn: "hideColumn", unhideColumn: "unhideColumn", sheetDelete: "sheetDelete", sheetRename: "sheetRename", sheetHide: "sheetHide", sheetDuplicate: "sheetDuplicate", sheetMoveLeft: "sheetMoveLeft", sheetMoveRight: "sheetMoveRight", invalidNameError: "invalidNameError" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetMessages]',
                    standalone: true
                }]
        }], propDecorators: { home: [{
                type: Input
            }], file: [{
                type: Input
            }], insert: [{
                type: Input
            }], formatTab: [{
                type: Input
            }], dataTab: [{
                type: Input
            }], saveFile: [{
                type: Input
            }], loadFile: [{
                type: Input
            }], bold: [{
                type: Input
            }], dataValidation: [{
                type: Input
            }], validationCellRange: [{
                type: Input
            }], validationCriteria: [{
                type: Input
            }], validationComparer: [{
                type: Input
            }], validationMinValue: [{
                type: Input
            }], validationMaxValue: [{
                type: Input
            }], validationStartValue: [{
                type: Input
            }], validationEndValue: [{
                type: Input
            }], validationValue: [{
                type: Input
            }], validationShowListButtonCheckbox: [{
                type: Input
            }], validationShowDateButtonCheckbox: [{
                type: Input
            }], validationIgnoreBlankCheckbox: [{
                type: Input
            }], validationOnInvalidData: [{
                type: Input
            }], validationRejectInput: [{
                type: Input
            }], validationShowWarning: [{
                type: Input
            }], validationShowHint: [{
                type: Input
            }], anyValueValidationCriteria: [{
                type: Input
            }], numberValidationCriteria: [{
                type: Input
            }], textValidationCriteria: [{
                type: Input
            }], dateValidationCriteria: [{
                type: Input
            }], customFormulaValidationCriteria: [{
                type: Input
            }], listValidationCriteria: [{
                type: Input
            }], greaterThanValidationComparer: [{
                type: Input
            }], lessThanValidationComparer: [{
                type: Input
            }], betweenValidationComparer: [{
                type: Input
            }], notBetweenValidationComparer: [{
                type: Input
            }], equalToValidationComparer: [{
                type: Input
            }], notEqualToValidationComparer: [{
                type: Input
            }], greaterThanOrEqualToValidationComparer: [{
                type: Input
            }], lessThanOrEqualToValidationComparer: [{
                type: Input
            }], validationHintMessage: [{
                type: Input
            }], validationHintTitle: [{
                type: Input
            }], italic: [{
                type: Input
            }], underline: [{
                type: Input
            }], format: [{
                type: Input
            }], fontFamily: [{
                type: Input
            }], fontSize: [{
                type: Input
            }], undo: [{
                type: Input
            }], redo: [{
                type: Input
            }], background: [{
                type: Input
            }], color: [{
                type: Input
            }], gridLines: [{
                type: Input
            }], addColumnLeft: [{
                type: Input
            }], addColumnRight: [{
                type: Input
            }], addRowBelow: [{
                type: Input
            }], addRowAbove: [{
                type: Input
            }], deleteColumn: [{
                type: Input
            }], deleteRow: [{
                type: Input
            }], wrap: [{
                type: Input
            }], align: [{
                type: Input
            }], alignHorizontal: [{
                type: Input
            }], alignVertical: [{
                type: Input
            }], alignLeft: [{
                type: Input
            }], alignCenter: [{
                type: Input
            }], alignRight: [{
                type: Input
            }], alignJustify: [{
                type: Input
            }], alignTop: [{
                type: Input
            }], alignMiddle: [{
                type: Input
            }], alignBottom: [{
                type: Input
            }], dialogApply: [{
                type: Input
            }], dialogCancel: [{
                type: Input
            }], dialogDelete: [{
                type: Input
            }], dialogRename: [{
                type: Input
            }], dialogInsert: [{
                type: Input
            }], dialogRemove: [{
                type: Input
            }], dialogRemoveLink: [{
                type: Input
            }], delete: [{
                type: Input
            }], rename: [{
                type: Input
            }], nameBox: [{
                type: Input
            }], formulaInput: [{
                type: Input
            }], addSheet: [{
                type: Input
            }], sheetsMenu: [{
                type: Input
            }], view: [{
                type: Input
            }], merge: [{
                type: Input
            }], mergeHorizontally: [{
                type: Input
            }], mergeVertically: [{
                type: Input
            }], mergeAll: [{
                type: Input
            }], unmerge: [{
                type: Input
            }], insertLink: [{
                type: Input
            }], increaseDecimal: [{
                type: Input
            }], decreaseDecimal: [{
                type: Input
            }], increaseFontSize: [{
                type: Input
            }], decreaseFontSize: [{
                type: Input
            }], openUnsupported: [{
                type: Input
            }], modifyMerged: [{
                type: Input
            }], cannotModifyDisabled: [{
                type: Input
            }], dialogOk: [{
                type: Input
            }], dialogError: [{
                type: Input
            }], duplicateSheetName: [{
                type: Input
            }], copy: [{
                type: Input
            }], cut: [{
                type: Input
            }], paste: [{
                type: Input
            }], hideRow: [{
                type: Input
            }], unhideRow: [{
                type: Input
            }], hideColumn: [{
                type: Input
            }], unhideColumn: [{
                type: Input
            }], sheetDelete: [{
                type: Input
            }], sheetRename: [{
                type: Input
            }], sheetHide: [{
                type: Input
            }], sheetDuplicate: [{
                type: Input
            }], sheetMoveLeft: [{
                type: Input
            }], sheetMoveRight: [{
                type: Input
            }], invalidNameError: [{
                type: Input
            }] } });
