/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Range, Sheet, SpreadsheetWidget, Workbook } from "@progress/kendo-spreadsheet-common";
/**
 * Provides the event data for the Spreadsheet `change` event.
 */
export interface SpreadsheetChangeEvent {
    /**
     * Specifies the selected `Range` in the active sheet.
     */
    range: Range;
    /**
     * Specifies the `SpreadsheetWidget` instance used in the Spreadsheet component.
     */
    sender: SpreadsheetWidget;
}
/**
 * Provides the event data for the Spreadsheet `excelExport` event.
 */
export interface SpreadsheetExcelExportEvent {
    /**
     * Specifies the `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * Specifies the Excel `Workbook` configuration object. Changes to the `Workbook` are reflected in the output Excel document.
     */
    workbook: Workbook;
    /**
     * Prevents the Spreadsheet from saving the generated file when invoked.
     */
    preventDefault: Function;
}
/**
 * Provides the event data for the Spreadsheet `excelImport` event.
 */
export interface SpreadsheetExcelImportEvent {
    /**
     * Specifies the `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * Specifies the selected file.
     */
    file: File | Blob;
    /**
     * Prevents the Spreadsheet from loading the selected file when invoked.
     */
    preventDefault: Function;
}
/**
 * Provides the event data for the Spreadsheet `activeSheetChange` event.
 */
export interface SpreadsheetActiveSheetChangeEvent {
    /**
     * Specifies the `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * Specifies the new active sheet.
     */
    sheet: Sheet;
}
